@@ -1,7 +1,3 @@
-# -*- coding: utf-8 -*-
-
-from __future__ import unicode_literals
-
 import re
 
 from django.core.exceptions import ValidationError
@@ -110,7 +106,6 @@ class UrlBBCodeTag(BBCodeTag):
     def render(self, value, option=None, parent=None):
         href = option if option else value
         href = replace(href, bbcode_settings.BBCODE_ESCAPE_HTML)
-        value = replace(value, bbcode_settings.BBCODE_ESCAPE_HTML)
         if '://' not in href and self._domain_re.match(href):
             href = 'http://' + href
         v = URLValidator()
